@@ -1,6 +1,7 @@
 fitmand <- function(x, trunc, start.value, ...){
   if (any(x <= 0)) stop ("All x must be positive")
-  if(class(x)!="rad") rad.tab <- rad(x)
+  ##if(class(x)!="rad") rad.tab <- rad(x)
+  if(!inherits(x, "rad")) rad.tab <- rad(x)
   else rad.tab <- x
   N <- max(rad.tab$rank)
   y <- rep(rad.tab$rank, rad.tab$abund)
