@@ -1,6 +1,7 @@
 fitzipf <- function(x, N, trunc, start.value, upper = 20, ...){
   if (any(x <= 0)) stop ("All x must be positive")
-  if(class(x)!="rad") rad.tab <- rad(x)
+  ##if(class(x)!="rad") rad.tab <- rad(x)
+  if(!inherits(x, "rad")) rad.tab <- rad(x)
   else rad.tab <- x
   y <- rep(rad.tab$rank, rad.tab$abund)
   dots <- list(...)
