@@ -8,5 +8,5 @@ qgs<-function(p, k, S, lower.tail = TRUE, log.p = FALSE){
   p[p==1] <- 1+1e-12
   Y <- 1:S
   X <- pgs(Y, k=k, S=S)
-  approx(x=X, y=Y, xout=p, method="constant", rule=2)$y
+  approx(x=X, y=Y, xout=p, method="constant", rule=2, ties="ordered")$y
 }
