@@ -22,6 +22,7 @@ setClass("rad", contains="data.frame", validity = function(object) {
 setClass("fitsad", contains="mle2", slots=c(sad="character", distr="character", trunc="numeric"))
 setClass("fitrad", contains="mle2", slots=c(rad="character", distr="character", trunc="numeric", rad.tab="rad"))
 
+
 distr.depr <- "The 'distr' slot of fitrad and fitsad objects have been deprecated. Please see ?distr"
 
 #' Summary for fitsad/fitrad calls
@@ -31,4 +32,10 @@ distr.depr <- "The 'distr' slot of fitrad and fitsad objects have been deprecate
 #' @rdname summary.sads-class
 setClass("summary.sads", contains="summary.mle2", slots=c(fixed="numeric"))
 
+
 setClass("likelregions", contains="list", slots=c(names="character", ratio="numeric"))
+setClass("histogram", contains = "list")
+setClass("coverpred", contains = "list") 
+
+
+setClass("fitsadC", contains="mle2", slots=c(sad="character", trunc="numeric", hist="histogram"))
